@@ -21,17 +21,9 @@ Pure Python module to hyphenate text, inspired by Ruby's Text::Hyphen.
 
 """
 
-from __future__ import unicode_literals
-
 import os
 import re
 
-try:
-    unichr
-except NameError:
-    # Python3
-    unichr = chr
-
 __all__ = ('Pyphen', 'LANGUAGES', 'language_fallback')
 
 # cache of per-file HyphDict objects
@@ -47,10 +39,15 @@ try:
 except ImportError:
     dictionaries_root = os.path.join(os.path.dirname(__file__), 'dictionaries')
 
-LANGUAGES = dict(
-    (filename[5:-4], os.path.join(dictionaries_root, filename))
-    for filename in os.listdir(dictionaries_root)
-    if filename.endswith('.dic'))
+LANGUAGES = {}
+for filename in sorted(os.listdir(dictionaries_root)):
+    if filename.endswith('.dic'):
+        name = filename[5:-4]
+        full_path = os.path.join(dictionaries_root, filename)
+        LANGUAGES[name] = full_path
+        short_name = name.split('_')[0]
+        if short_name not in LANGUAGES:
+            LANGUAGES[short_name] = full_path
 
 
 def language_fallback(language):
@@ -129,14 +126,14 @@ class HyphDict(object):
                 charset = 'cp1251'
             for pattern in stream:
                 pattern = pattern.decode(charset).strip()
-                if (not pattern or
-                        pattern.startswith('%') or
-                        pattern.startswith('#')):
+                if not pattern or pattern.startswith((
+                        '%', '#', 'LEFTHYPHENMIN', 'RIGHTHYPHENMIN',
+                        'COMPOUNDLEFTHYPHENMIN', 'COMPOUNDRIGHTHYPHENMIN')):
                     continue
 
                 # replace ^^hh with the real character
                 pattern = parse_hex(
-                    lambda match: unichr(int(match.group(1), 16)), pattern)
+                    lambda match: chr(int(match.group(1), 16)), pattern)
 
                 # read nonstandard hyphen alternatives
                 if '/' in pattern:
